==> bibledit-cloud_5.0.964.orig.tar.gz: bibledit-cloud-5.0.964/images/fetch.cpp <==
/*
 Copyright (©) 2003-2021 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */


#include <images/fetch.h>
#include <filter/roles.h>
#include <filter/string.h>
#include <filter/url.h>
#include <webserver/request.h>
#include <database/bibleimages.h>


string images_fetch_url ()
{
  return "images/fetch";
}


bool images_fetch_acl (void * webserver_request)
{
  return Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ());
}


string images_fetch (void * webserver_request)
{
  Webserver_Request * request = (Webserver_Request *) webserver_request;
  
  // Image name.
  string image = request->query ["image"];

  // Set the HTTP GET parameter to the image name,
  // so the server will return the appropriate Mime type for this image.
  request->get = image;

  // Return the raw image data for sending off to the browser.
  Database_BibleImages database_bibleimages;
  return database_bibleimages.get (image);
}

==> bibledit-cloud_5.0.978.orig.tar.gz: bibledit-cloud-5.0.978/images/fetch.cpp <==
/*
 Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */


#include <images/fetch.h>
#include <filter/roles.h>
#include <filter/string.h>
#include <filter/url.h>
#include <webserver/request.h>
#include <database/bibleimages.h>


string images_fetch_url ()
{
  return "images/fetch";
}


bool images_fetch_acl (void * webserver_request)
{
  return Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ());
}


string images_fetch (void * webserver_request)
{
  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
  
  // Image name.
  string image = request->query ["image"];

  // Set the HTTP GET parameter to the image name,
  // so the server will return the appropriate Mime type for this image.
  request->get = image;

  // Return the raw image data for sending off to the browser.
  Database_BibleImages database_bibleimages;
  return database_bibleimages.get (image);
}
